@@ -13,23 +13,24 @@ use threads::shared;
 use Graphics::Framebuffer;
 use Time::HiRes qw(sleep time);
 use List::Util qw(shuffle);
+
 # use Data::Dumper::Simple;
 
-my $args = join('',@ARGV);
+my $args = join('', @ARGV);
 
-my $file       = 0;
-$file          = 1 if ($args =~ /file/i);
-my $errors     = 0;
-$errors        = 1 if ($args =~ /errors/i);
-my $auto       = 0;
-$auto          = 1 if ($args =~ /auto/i);
+my $file = 0;
+$file = 1 if ($args =~ /file/i);
+my $errors = 0;
+$errors = 1 if ($args =~ /errors/i);
+my $auto = 0;
+$auto = 1 if ($args =~ /auto/i);
 my $fullscreen = 0;
-$fullscreen    = 1 if ($args =~ /full/i);
+$fullscreen = 1 if ($args =~ /full/i);
 
 my @fbs;
 foreach my $p (qw(/dev/graphics/fb /dev/fb)) {
-    foreach my $b (0..31) {
-        push(@fbs,"$p$b") if (-e "$p$b");
+    foreach my $b (0 .. 31) {
+        push(@fbs, "$p$b") if (-e "$p$b");
     }
 }
 
@@ -39,48 +40,53 @@ $SIG{'QUIT'} = sub {
     print STDERR "\nExiting..\n";
     $RUNNING = 0;
     sleep 1;
-    $SIG{'QUIT'} = sub {exit(1);};
+    $SIG{'QUIT'} = sub { exit(1); };
 };
 $SIG{'INT'} = sub {
     print STDERR "\nExiting..\n";
     $RUNNING = 0;
     sleep 1;
-    $SIG{'INT'} = sub {exit(1);};
+    $SIG{'INT'} = sub { exit(1); };
 };
 
 our @pics;
 
 my @f;
 foreach my $fb (@fbs) {
-    push(@f,Graphics::Framebuffer->new(
-        'FB_DEVICE'   => $fb,
-        'SPLASH'      => 0,
-        'SHOW_ERRORS' => $errors,
-        'FILE_MODE'   => $file
-    ));
-}
+    push(
+        @f,
+        Graphics::Framebuffer->new(
+            'FB_DEVICE'   => $fb,
+            'SPLASH'      => 0,
+            'SHOW_ERRORS' => $errors,
+            'FILE_MODE'   => $file
+        )
+    );
+} ## end foreach my $fb (@fbs)
 
 gather($ARGV[-1]);
 
 # print STDERR Dumper(\@pics);exit;
 
-
 foreach my $F (@f) {
-    push(@thr,threads->create(
-        sub {
-            my $FB = shift;
-            my $p  = shift;
-            system('clear');
-            $FB->cls('OFF');
+    push(
+        @thr,
+        threads->create(
+            sub {
+                my $FB = shift;
+                my $p  = shift;
+                system('clear');
+                $FB->cls('OFF');
 
-            show($FB,$p);
-            $FB->cls('ON');
-        },
-        $F,
-        scalar(@pics)
-    ));
-}
-while($RUNNING) {
+                show($FB, $p);
+                $FB->cls('ON');
+            },
+            $F,
+            scalar(@pics)
+        )
+    );
+} ## end foreach my $F (@f)
+while ($RUNNING) {
     sleep 1;
 }
 $f[0]->cls('ON');
@@ -90,32 +96,31 @@ foreach my $t (@thr) {
 
 exit(0);
 
-
 sub gather {
     my $path = shift;
     chop($path) if ($path =~ /\/$/);
-    opendir(my $DIR,$path);
+    opendir(my $DIR, $path);
     chomp(my @dir = readdir($DIR));
     closedir($DIR);
-    return if (grep(/\.nopmedia/,@dir));
+    return if (grep(/\.nopmedia/, @dir));
     foreach my $file (@dir) {
         next if ($file =~ /^\.+/);
         if (-d "$path/$file") {
             gather("$path/$file");
         } elsif (-f "$path/$file" && $file =~ /\.(jpg|jpeg|gif|tiff|bmp|png)$/i) {
-            push(@pics,"$path/$file");
+            push(@pics, "$path/$file");
         }
-    }
-}
+    } ## end foreach my $file (@dir)
+} ## end sub gather
 
 sub show {
-    my $FB = shift;
-    my $p  = shift;
+    my $FB  = shift;
+    my $p   = shift;
     my $idx = 0;
     @pics = shuffle(@pics);
     while ($RUNNING) {
         my $name = $pics[$idx];
-        print_it($FB,"Loading image $name");
+        print_it($FB, "Loading image $name");
         my $image;
         unless ($fullscreen) {
             $image = $FB->load_image(
@@ -135,33 +140,34 @@ sub show {
                     'autolevels' => $auto
                 }
             );
-        }
-#        warn Dumper($image);exit;
-        last unless($RUNNING);
+        } ## end else
+
+        #        warn Dumper($image);exit;
+        last unless ($RUNNING);
         if (defined($image)) {
             $FB->cls();
             if (ref($image) eq 'ARRAY') {
                 my $s = time + 8;
                 while (time <= $s) {
-                    last unless($RUNNING);
+                    last unless ($RUNNING);
                     foreach my $frame (0 .. (scalar(@{$image}) - 1)) {
-                        last unless($RUNNING);
+                        last unless ($RUNNING);
                         my $begin = time;
                         $FB->blit_write($image->[$frame]);
                         my $delay = ($image->[$frame]->{'tags'}->{'gif_delay'} / 100) - (time - $begin);
                         sleep $delay if ($delay > 0);
-                    }
-                }
+                    } ## end foreach my $frame (0 .. (scalar...))
+                } ## end while (time <= $s)
             } else {
                 $FB->cls();
                 $FB->blit_write($image);
                 sleep 3;
             }
-        }
+        } ## end if (defined($image))
         $idx++;
         $idx = 0 if ($idx >= $p);
-    }
-}
+    } ## end while ($RUNNING)
+} ## end sub show
 
 sub print_it {
     my $fb      = shift;
